fake_dict = {
    "type": "framework",
    "name": "Orionis Framework",
    "features": {
        "authentication": True,
        "csrf_protection": True,
        "session_management": True,
        "logging": True,
        "error_handling": True,
        "database_integration": True,
        "template_engine": True,
        "api_support": True,
        "routing": True
    }
}